# Solving Puzzles with LLMs and Reasoning Models
This project explores the performance of two language models, LLaMa-3.1-8b-instant and LLaMa-3.3-70b-specdec, in solving a collection of riddles. The models are evaluated on their ability to solve a variety of riddles, with a focus on logical deduction, reasoning, and problem-solving strategies.

## Models Tested
- LLaMa-3.1-8b-instant: A general-purpose language model with basic reasoning capabilities.

- LLaMa-3.3-70b-specdec: A reasoning-focused model designed to handle more complex, multi-step problem-solving tasks.

## Riddles Dataset
The dataset consists of 28 riddles from a variety of categories, including:

- Logic puzzles

- Mathematical riddles

- Verbal reasoning challenges

## Installation
To run this project, clone the repository and install the required dependencies:

``` python
# Install dependencies
pip install -r requirements.txt
```

## Usage
To test the models on a set of riddles, you can run the following script:

```
python llama.py
```

Make sure to have your models set up before running the script.

## Future Work
- Data Contamination: Measure the memorization and exploitation of patterns within the models' training data.

- Fine-Tuning: Explore how fine-tuning models on logic-based datasets could improve their performance on riddles.

- Chain-of-Thought (CoT): Investigate the use of prompt-engineering techniques such as CoT reasoning to help models reason systematically.

## ## Acknowledgements

This project leveraged the following AI tools for assistance in code generation and problem-solving:

- **GitHub Copilot**: Used for suggesting code snippets and completing functions during development.
- **ChatGPT**: Utilized for generating ideas, explanations, and troubleshooting during the research and writing stages of the project.

We acknowledge the valuable contributions of these tools in enhancing productivity and helping overcome technical challenges.

## Contact
Barbosa Monteiro Diogo - monteiro@cl.uni-heidelberg.de